@@ -255,13 +255,13 @@ class GustyBuilder:
                 handle_user_constructors(kwargs["dag_constructors"])
             )
 
-        # Generate loader with dag_constructors
-        self.loader = generate_loader(dag_constructors)
-
         # Generate runner with dag_constructors
         runner_context = {k.strip("!"): v for k, v in dag_constructors.items()}
         self.runner = Runner(**runner_context)
 
+        # Generate loader with dag_constructors
+        self.loader = generate_loader(dag_constructors)
+
         self.schematic = create_schematic(dag_dir, self.parsers)
 
         # DAG defaults - everything that's not task_group_defaults or wait_for_defaults
@@ -336,9 +336,9 @@ class GustyBuilder:
                 and "default_args" in level_metadata.keys()
             ):
                 # metadata defaults
-                metadata_default_args = metadata_defaults["default_args"]
+                metadata_default_args = metadata_defaults["default_args"].copy()
                 # level_metadata (provided via METADATA.yml)
-                level_default_args = level_metadata["default_args"]
+                level_default_args = level_metadata["default_args"].copy()
                 # metadata defaults updated with level_metadata
                 metadata_default_args.update(level_default_args)
                 # updated and resolved attached back to level_metadata
