@@ -1,8 +1,6 @@
 import pytest
-import os
-from airflow import DAG
-from datetime import datetime, timedelta
-from airflow.utils.dates import days_ago
+from datetime import timedelta
+from gusty.utils import days_ago
 from gusty import create_dag
 
 
