@@ -1,7 +1,7 @@
 import pytest
 from gusty import create_dag
-from datetime import datetime, timedelta
-from airflow.utils.dates import days_ago
+from datetime import timedelta
+from gusty.utils import days_ago
 
 ###############
 ## FIXTURES ##
